@@ -197,7 +197,7 @@ sub new {
 my $maybe_setter = sub {
     my ($method) = @_;
     sub {
-        @_ == 2 or fp_croak_nargs 2;
+        @_ == 2 or fp_croak_arity 2;
         my ($self, $v) = @_;
         my $set_maybe_method = "set_maybe_${method}";
         defined $v
@@ -274,7 +274,7 @@ sub possibly_restore_settings {
 }
 
 sub saving {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     my ($self, $proc) = @_;
     sub {
         &$proc(@_);
@@ -512,7 +512,7 @@ our $use_warnings = q{use warnings; use warnings FATAL => 'uninitialized';};
 
 sub eval_code {
     my $self = shift;
-    @_ == 5 or fp_croak_nargs 5;
+    @_ == 5 or fp_croak_arity 5;
     my ($code, $in_package, $maybe_lexicals, $maybe_kept_results,
         $maybe_lexical_persistence)
         = @_;
