@@ -63,30 +63,33 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Struct::Show;
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use base 'FP::Abstract::Show';
 
 sub FP_Show_show {
-    my ($self,$show)=@_;
-    my $class= ref ($self);
-    length $class
-      or die "FP_Show_show called on non-object: $self";
-    my $fieldnames= do {
+    my ($self, $show) = @_;
+    my $class = ref($self);
+    length $class or die "FP_Show_show called on non-object: $self";
+    my $fieldnames = do {
         no strict 'refs';
         \@{"${class}::__Struct__fields"}
     };
-    my @class_parts= split /::/, $class;
-    ($class_parts[-1]."(".
-     join(", ",
-          map {
-              my $fieldname= FP::Struct::field_name($_);
-              &$show($self->$fieldname)
-          } FP::Struct::all_fields([$class])).
-     ")")
+    my @class_parts = split /::/, $class;
+    (
+        $class_parts[-1] . "(" . join(
+            ", ",
+            map {
+                my $fieldname = FP::Struct::field_name($_);
+                &$show($self->$fieldname)
+            } FP::Struct::all_fields([$class])
+            )
+            . ")"
+    )
 }
 
 1
