@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2015-2020 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -23,19 +23,19 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FunctionalPerl::ModuleList;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(modulenamelist modulepathlist);
-@EXPORT_OK=qw();
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
-
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
+our @EXPORT      = qw(modulenamelist modulepathlist);
+our @EXPORT_OK   = qw();
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 use Chj::xopen 'xopen_read';
 
-our $moduleandpathlist; # [[ name, path ] ...]
+our $moduleandpathlist;    # [[ name, path ] ...]
 
 sub moduleandpathlist {
     $moduleandpathlist //= do {
@@ -44,7 +44,7 @@ sub moduleandpathlist {
         local $_;
         while (<$f>) {
             chomp;
-            my $path= $_;
+            my $path = $_;
             next unless s/\.pm$//;
             s|^(lib\|meta\|htmlgen)/|| or die "no match: $_";
             s|/|::|sg;
@@ -56,11 +56,11 @@ sub moduleandpathlist {
 }
 
 sub modulenamelist {
-    [ map { $$_[0] } @{moduleandpathlist()} ]
+    [map { $$_[0] } @{ moduleandpathlist() }]
 }
 
 sub modulepathlist {
-    [ map { $$_[1] } @{moduleandpathlist()} ]
+    [map { $$_[1] } @{ moduleandpathlist() }]
 }
 
 1
